
# Spinning Up Examples

Those examples are essentially ports of Kai Arulkumaran's [spinning-up-basic](https://github.com/Kaixhin/spinning-up-basic) on top of cherry.
They single-file implementations using the `Pendulum-v1` environment, and were originally implemented to illustrate the algorithms presented in Josh Achiam's [Spinning Up in Deep RL](http://spinningup.openai.com/) course.

**Note** We use those implementations in our [integration tests](../../tests/integration/).

**State** All implementations replicate the original repo.

## Requirements

* Gym, torch, and cherry installed.
